Handle the single error for normal or t distributions
.handleSingleErrTypeNormOrTFoceiBase(env, pred1)Environment for the parsed model
The data.frame of the current error
A list of the lines added. The lines will contain
rx_yj_ which is an integer that corresponds to the transformation type.
rx_lambda_ is the transformation lambda
rx_low_ The lower boundary of the transformation
rx_hi_ The upper boundary of the transformation
rx_pred_f_ The prediction function
rx_pred_ The transformed prediction function
rx_r_ The transformed variance