Skip to contents

Convert an event table to a data.table

Usage

# S3 method for class 'rxEt'
as.data.table(x, keep.rownames = FALSE, ...)

Arguments

x

An R object.

keep.rownames

Default is FALSE. If TRUE, adds the input object's names as a separate column named "rn". keep.rownames = "id" names the column "id" instead. For lists and when calling data.table(), names from the first named vector are extracted and used as row names, similar to data.frame() behavior.

...

Additional arguments to be passed to or from other methods.

Value

data.table of event table