Verify that a compartment would be new to the model
Usage
assertCompartmentNew(ui, x)
Arguments
- ui
is the model to test that a model paramet exists
- x
The value to test
Value
The value or an error
See also
Other Assertions:
assertCompartmentExists(),
assertCompartmentName(),
assertRxUi(),
assertVariableExists(),
assertVariableNew(),
rxPriorBuildSpec(),
rxPriorLogDensity(),
rxPriorOmegaToCholOmegaInvGrad(),
rxUiPriors(),
testIniDf(),
testRxUnbounded()
Author
Matthew Fidler & Bill Denney