Assert a variable would be new to the model
Arguments
- ui
rxode2 ui model
- x
would the variable x variable be new in the model
Value
nothing, but will error if x would not be new
See also
Other Assertions:
assertCompartmentExists(),
assertCompartmentName(),
assertCompartmentNew(),
assertRxUi(),
assertVariableExists(),
rxPriorBuildSpec(),
rxPriorLogDensity(),
rxPriorOmegaToCholOmegaInvGrad(),
rxUiPriors(),
testIniDf(),
testRxUnbounded()