| coef.rxode2 | R Documentation |
This returns the parameters , state variables
## S3 method for class 'rxode2'
coef(object, ...)
object |
is an rxode2 object |
... |
ignored arguments |
a rxCoef object with the following
params is a list of strings for parameters for the rxode2 object
state is a list of strings for the names of each state in
the rxode2 object.
ini is the model specified default values for the
parameters.
rxode2 is the referring rxode2 object
Matthew L.Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.