Handle the single error for normal or t distributions
Source:R/err-foceiBase.R
dot-handleSingleErrTypeNormOrTFoceiBase.RdHandle the single error for normal or t distributions
Usage
.handleSingleErrTypeNormOrTFoceiBase(
env,
pred1,
errNum = 1L,
rxPredLlik = TRUE,
arNorm = FALSE
)Arguments
- env
Environment for the parsed model
- pred1
The
data.frameof the current error- errNum
The number of the error specification in the nlmixr2 model
- rxPredLlik
A boolean indicating if the log likelihood should be calculated for non-normal distributions. By default
TRUE.- arNorm
A boolean; when
TRUE, emit the AR(1) norm (conditional mean/variance) form used by the focei inner model. By defaultFALSE.
Value
A list of the lines added. The lines will contain
rx_yj_which is an integer that corresponds to the transformation type.rx_lambda_is the transformation lambdarx_low_The lower boundary of the transformationrx_hi_The upper boundary of the transformationrx_pred_f_The prediction functionrx_pred_The transformed prediction functionrx_r_The transformed variance