Calculate the lambdas and coefficients of the two compartment model
Source:R/linCmt.R
dot-solComp2.RdCalculate the lambdas and coefficients of the two compartment model

R/linCmt.R
dot-solComp2.RdCalculate the lambdas and coefficients of the two compartment model