Skip to contents

Outside of an rxode2 call the most recent environment becomes the primary one; inside an rxode2 call (see .udfEnvLocal()) the call's environment is kept and env is only added to the search list.

Usage

.udfEnvSet(env)

Arguments

env

environment where user defined functions are queried. If NULL return current environment

Value

environment

Author

Matthew L. Fidler