head.rxSolveOom: First rows of an out-of-memory solved object

View source: R/rxOom.R

head.rxSolveOomR Documentation

First rows of an out-of-memory solved object

Description

Reads only the first n rows from the parquet (or rds) chunks, preferring DuckDB (which pushes the row limit into the parquet reader) and falling back to arrow / rds.

Usage

## S3 method for class 'rxSolveOom'
head(x, n = 6L, ...)

Arguments

x

An rxSolveOom object.

n

Number of rows to return.

...

Ignored.

Value

A data.frame with the first n rows.


rxode2 documentation built on July 28, 2026, 5:08 p.m.