indLin: Transition ODEs written in d/dt() format to matrix...

View source: R/indLin.R

indLinR Documentation

Transition ODEs written in d/dt() format to matrix exponential / inductive linearization format

Description

Transition ODEs written in d/dt() format to matrix exponential / inductive linearization format

Usage

indLin(model, doConst = FALSE, calcSens = NULL)

rxOdeToIndLin(model, doConst = FALSE, calcSens = NULL)

rxToIndLin(model, doConst = FALSE, calcSens = NULL)

Arguments

model

rxode2 model, text, or function

doConst

Replace constants with values; By default this is FALSE.

calcSens

A character vector of parameter names for which sensitivities should be calculated.

Value

A character string representing the matrix exponential model code

Author(s)

Matthew L. Fidler


rxode2 documentation built on July 28, 2026, 5:08 p.m.