| llikF | R Documentation |
log likelihood and derivatives for F distribution
llikF(x, df1, df2, full = FALSE)
x |
variable that is distributed by f distribution |
df1, df2 |
degrees of freedom. |
full |
Add the data frame showing x, mean, sd as well as the fx and derivatives |
In an rxode2() model, you can use llikF() but you have to
use the x and rate arguments. You can also get the derivative of df1 and df2 with
llikFDdf1() and llikFDdf2().
data frame with fx for the log pdf value of with dDf1 and dDf2
that has the derivatives with respect to the df1/df2 parameters at
the observation time-point
Matthew L. Fidler
x <- seq(0.001, 5, length.out = 100)
llikF(x^2, 1, 5)
model <- function(){
model({
fx <- llikF(time, df1, df2)
dMean <- llikFDdf1(time, df1, df2)
dSd <- llikFDdf2(time, df1, df2)
})
}
et <- et(x)
et$df1 <- 1
et$df2 <- 5
rxSolve(model, et)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.