| llikT | R Documentation |
Log likelihood of T and it's derivatives (from stan)
llikT(x, df, mean = 0, sd = 1, full = FALSE)
x |
Observation |
df |
degrees of freedom ( |
mean |
Mean for the likelihood |
sd |
Standard deviation for the likelihood |
full |
Add the data frame showing x, mean, sd as well as the fx and derivatives |
In an rxode2() model, you can use llikT() but you have to
use all arguments. You can also get the derivative of df, mean and sd with
llikTDdf(), llikTDmean() and llikTDsd().
data frame with fx for the log pdf value of with dDf
dMean and dSd that has the derivatives with respect to the parameters at
the observation time-point
Matthew L. Fidler
x <- seq(-3, 3, length.out = 21)
llikT(x, 7, 0, 1)
llikT(x, 15, 0, 1, full=TRUE)
et <- et(-3, 3, length.out=10)
et$nu <- 7
et$mean <- 0
et$sd <- 1
model <- function() {
model({
fx <- llikT(time, nu, mean, sd)
dDf <- llikTDdf(time, nu, mean, sd)
dMean <- llikTDmean(time, nu, mean, sd)
dSd <- llikTDsd(time, nu, mean, sd)
})
}
rxSolve(model, et)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.