| llikUnif | R Documentation |
log likelihood and derivatives for Unif distribution
llikUnif(x, alpha, beta, full = FALSE)
x |
variable distributed by a uniform distribution |
alpha |
is the lower limit of the uniform distribution |
beta |
is the upper limit of the distribution |
full |
Add the data frame showing x, mean, sd as well as the fx and derivatives |
In an rxode2() model, you can use llikUnif() but you have to
use the x and rate arguments. You can also get the derivative of alpha or beta with
llikUnifDalpha() and llikUnifDbeta().
data frame with fx for the log pdf value of with dProb
that has the derivatives with respect to the prob parameters at
the observation time-point
Matthew L. Fidler
llikUnif(1, -2, 2)
et <- et(seq(1,1, length.out=4))
et$alpha <- -2
et$beta <- 2
model <- function() {
model({
fx <- llikUnif(time, alpha, beta)
dAlpha<- llikUnifDalpha(time, alpha, beta)
dBeta <- llikUnifDbeta(time, alpha, beta)
})
}
rxSolve(model, et)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.