| llikWeibull | R Documentation |
log likelihood and derivatives for Weibull distribution
llikWeibull(x, shape, scale, full = FALSE)
x |
variable distributed by a Weibull distribution |
shape, scale |
shape and scale parameters, the latter defaulting to 1. |
full |
Add the data frame showing x, mean, sd as well as the fx and derivatives |
In an rxode2() model, you can use llikWeibull() but you have to
use the x and rate arguments. You can also get the derivative of shape or scale with
llikWeibullDshape() and llikWeibullDscale().
data frame with fx for the log pdf value of with dProb
that has the derivatives with respect to the prob parameters at
the observation time-point
Matthew L. Fidler
llikWeibull(1, 1, 10)
# rxode2 can use this too:
et <- et(seq(0.001, 1, length.out=10))
et$shape <- 1
et$scale <- 10
model <- function() {
model({
fx <- llikWeibull(time, shape, scale)
dShape<- llikWeibullDshape(time, shape, scale)
dScale <- llikWeibullDscale(time, shape, scale)
})
}
rxSolve(model, et)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.