Current Condition for rxode2 object
Arguments
- obj
rxode2 object
- condition
If specified and is one of the conditions in the rxode2 object (as determined by
rxExpandIfElse()), assign the rxode2 current condition to this parameter. If the condition is not one of the known condition, the condition is set toNULL, implying no conditioning currently used.