Expand if/else clauses into multiple different types of lines.
Arguments
- model
Model can be a character, or a rxode2 model. It needs to have normalized syntax, that is
if (...){}has to be on the same line. Theelsestatement must be on its own line with the closing bracket of theifstatement on the previous line. Thiselsestatement must also contain the opening bracket, like the codeelse {}- removeInis
A boolean indicating if parameter initializations should be removed from the model.
- removePrint
A boolean indicating if printing statements should be removed from the model.