rxRawToC: Convert a Raw Vector or R object to C Code

View source: R/rxRaw.R

rxRawToCR Documentation

Convert a Raw Vector or R object to C Code

Description

This function converts a raw vector or R object to C code that is used in the rxode2 model

Usage

rxRawToC(raw, type = c("xz", "base", "bzip2"))

Arguments

raw

vector or R object to convert

type

serialization type; one of "base", "xz" or "bzip2".

Value

raw vector for conversion to C in the codegen procedure

Author(s)

Matthew L. Fidler

Examples


rxRawToC(mtcars)


rxode2 documentation built on July 28, 2026, 5:08 p.m.