| rxResidualError | R Documentation |
A description of Rode2 supported residual errors
rxResidualError
A data frame with 6 columns and 183 rows
A description of the type of residual error
For additive and proportional what functional form is used
The type of transformation that is done on the DV and the prediction
Example code for the residual error type
The type of add+prop residual error default that would be equivalent
what the left handed side of the specification represents, either a response variable, or a compartment specification
The transformation-based and autocorrelated (ar(), AR(1)) residual
error models follow Karlsson MO, Beal SL, Sheiner LB. Three new residual
error models for population PK/PD analyses. J Pharmacokinet Biopharm.
1995;23(6):651-672. doi:10.1007/BF02353466.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.