rxUdfUi: This function is called when processing rxode2 user functions...

View source: R/rudfui.R

rxUdfUi.evid_R Documentation

This function is called when processing rxode2 user functions from the models

Description

This function is called when processing rxode2 user functions from the models

Usage

## S3 method for class 'evid_'
rxUdfUi(fun)

## S3 method for class 'bolus'
rxUdfUi(fun)

## S3 method for class 'infuse'
rxUdfUi(fun)

## S3 method for class 'infuseDur'
rxUdfUi(fun)

## S3 method for class 'replace'
rxUdfUi(fun)

## S3 method for class 'multiply'
rxUdfUi(fun)

## S3 method for class 'phantom'
rxUdfUi(fun)

## S3 method for class 'obs'
rxUdfUi(fun)

rxUdfUi(fun)

## S3 method for class 'rinbinom'
rxUdfUi(fun)

Arguments

fun

this is the function that needs to be parsed and changed. This is a R language expression

Value

This needs to return a list with the following elements:

  • iniDf – the modified initial estimate data.frame

  • before – any model code that needs to be added before the current line

  • after – any model code that needs to be added after the current line

  • replace – replacement code for this user function

Author(s)

Matthew L. Fidler


rxode2 documentation built on July 28, 2026, 5:08 p.m.