| rxUdfUiEst | R Documentation |
Return the current estimation method for the UI processing
rxUdfUiEst(value)
value |
when specified, this assigns the character value of the estimation method or NULL if there is nothing being estimated |
value of the estimation method being processed or NULL
Matthew L. Fidler
Other User functions:
linMod(),
rxUdfUiData(),
rxUdfUiIniLhs(),
rxUdfUiMv(),
rxUdfUiNum(),
rxUdfUiParsing()
rxUdfUiEst()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.