| rxUdfUiExpr | R Documentation |
Here it means that it evaluates to a variable or a number.
rxUdfUiExpr(expr, env = parent.frame())
expr |
the R language expression to evaluate |
env |
the environment in which to evaluate the expression |
expression
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.