| rxUdfUiFlag | R Documentation |
This is useful when writing replacement UI functions
rxUdfUiFlag(expr, arg = "arg", funName = "fun", env = baseenv())
expr |
expression to evaluate |
arg |
argument name for error messages for the argument name
in the |
funName |
function name for the error message for the argument
name in the |
env |
the environment in which to evaluate the expression (in case it is numeric) |
logical value of the expression if it can be evaluated to a
scalar TRUE/FALSE value, otherwise an error is thrown.
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.