rxUdfUiIsValue: Is the expression actually equal to a value?

View source: R/rudfui.R

rxUdfUiIsValueR Documentation

Is the expression actually equal to a value?

Description

This is used to determine if the location and scale parameters are actually equal to their default values, which allows for more efficient translation to expit expressions when possible.

Usage

rxUdfUiIsValue(expr, value, env = baseenv())

Arguments

expr

the R language expression to evaluate

value

the value to compare against

env

the environment in which to evaluate the expression

Value

TRUE if the expression evaluates to a scalar value equal to the specified value, FALSE otherwise

Author(s)

Matthew L. Fidler


rxode2 documentation built on July 28, 2026, 5:08 p.m.