| stat_cens | R Documentation |
This is a censoring geom that shows the left or right censoring specified in the nlmixr input data-set or fit
stat_cens(
mapping = NULL,
data = NULL,
position = "identity",
show.legend = NA,
inherit.aes = TRUE,
width = 0.01,
...
)
geom_cens(
mapping = NULL,
data = NULL,
position = "identity",
show.legend = NA,
inherit.aes = TRUE,
width = 0.01,
...
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
width |
represents the width (in \ censoring box |
... |
Other arguments passed on to
|
Requires the following aesthetics:
x represents the independent variable, often the time scale
y represents the dependent variable
Plus exactly one of these aesthetic forms (the two forms cannot be mixed):
lower and upper give the lower and upper bounds of the censoring
interval directly. Both must be supplied. Use -Inf/Inf for an
unbounded side; use NA on both for observed (non-censored) rows.
cens (with optional limit) gives the censoring indicator
(-1 right censored, 0 not censored, 1 left censored) and, when
limit is also supplied, the associated limit value. Internally
converted to lower/upper.
Will add boxes representing the areas of the fit that were censored.
This returns a ggplot2 stat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.