This function tests if this object is a iniDf as needed by the UI
Usage
testIniDf(iniDf)
assertIniDf(iniDf, extra = "", .var.name = .vname(iniDf), null.ok = FALSE)
Arguments
- iniDf
the object to test if it is a rxode2 ui iniDf data.frame
information to append to the error message
- .var.name
[character(1)]
Name of the checked object to print in assertions. Defaults to
the heuristic implemented in vname.
- null.ok
[logical(1)]
If set to TRUE, x may also be NULL.
In this case only a type check of x is performed, all additional checks are disabled.
Value
boolean, indicating if the object is a valid initialization data frame
See also
Other Assertions:
assertCompartmentExists(),
assertCompartmentName(),
assertCompartmentNew(),
assertRxUi(),
assertVariableExists(),
assertVariableNew(),
rxPriorBuildSpec(),
rxPriorLogDensity(),
rxPriorOmegaToCholOmegaInvGrad(),
rxUiPriors(),
testRxUnbounded()
Examples
testIniDf(TRUE)
#> [1] FALSE