Convert an event table to a data.table
Arguments
- x
An R object.
- keep.rownames
Default is
FALSE. IfTRUE, adds the input object's names as a separate column named"rn".keep.rownames = "id"names the column"id"instead. For lists and when callingdata.table(), names from the first named vector are extracted and used as row names, similar todata.frame()behavior.- ...
Additional arguments to be passed to or from other methods.