assertCompartmentNew: Verify that a compartment would be new to the model

View source: R/assert.R

assertCompartmentNewR Documentation

Verify that a compartment would be new to the model

Description

Verify that a compartment would be new to the model

Usage

assertCompartmentNew(ui, x)

Arguments

ui

is the model to test that a model paramet exists

x

The value to test

Value

The value or an error

Author(s)

Matthew Fidler & Bill Denney

See Also

Other Assertions: assertCompartmentExists(), assertCompartmentName(), assertRxUi(), assertVariableExists(), assertVariableNew(), testIniDf(), testRxUnbounded()


rxode2 documentation built on July 28, 2026, 5:08 p.m.