| assertCompartmentNew | R Documentation |
Verify that a compartment would be new to the model
assertCompartmentNew(ui, x)
ui |
is the model to test that a model paramet exists |
x |
The value to test |
The value or an error
Matthew Fidler & Bill Denney
Other Assertions:
assertCompartmentExists(),
assertCompartmentName(),
assertRxUi(),
assertVariableExists(),
assertVariableNew(),
testIniDf(),
testRxUnbounded()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.