| assertVariableNew | R Documentation |
Assert a variable would be new to the model
assertVariableNew(ui, x)
ui |
rxode2 ui model |
x |
would the variable |
nothing, but will error if x would not be new
Matthew L. Fidler
Other Assertions:
assertCompartmentExists(),
assertCompartmentName(),
assertCompartmentNew(),
assertRxUi(),
assertVariableExists(),
testIniDf(),
testRxUnbounded()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.