| .handleSingleErrTypeNormOrTFoceiBase | R Documentation |
Handle the single error for normal or t distributions
.handleSingleErrTypeNormOrTFoceiBase(
env,
pred1,
errNum = 1L,
rxPredLlik = TRUE
)
env |
Environment for the parsed model |
pred1 |
The |
errNum |
The number of the error specification in the nlmixr2 model |
rxPredLlik |
A boolean indicating if the log likelihood should
be calculated for non-normal distributions. By default |
A list of the lines added. The lines will contain
rx_yj_ which is an integer that corresponds to the
transformation type.
rx_lambda_ is the transformation lambda
rx_low_ The lower boundary of the transformation
rx_hi_ The upper boundary of the transformation
rx_pred_f_ The prediction function
rx_pred_ The transformed prediction function
rx_r_ The transformed variance
Matthew Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.