| head.rxSolveOom | R Documentation |
Reads only the first n rows from the parquet (or rds) chunks,
preferring DuckDB (which pushes the row limit into the parquet reader) and
falling back to arrow / rds.
## S3 method for class 'rxSolveOom'
head(x, n = 6L, ...)
x |
An |
n |
Number of rows to return. |
... |
Ignored. |
A data.frame with the first n rows.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.