| indLin | R Documentation |
Transition ODEs written in d/dt() format to matrix exponential / inductive linearization format
indLin(model, doConst = FALSE, calcSens = NULL)
rxOdeToIndLin(model, doConst = FALSE, calcSens = NULL)
rxToIndLin(model, doConst = FALSE, calcSens = NULL)
model |
rxode2 model, text, or function |
doConst |
Replace constants with values; By default this is |
calcSens |
A character vector of parameter names for which sensitivities should be calculated. |
A character string representing the matrix exponential model code
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.