| llikGeom | R Documentation |
log likelihood and derivatives for Geom distribution
llikGeom(x, prob, full = FALSE)
x |
variable distributed by a geom distribution |
prob |
probability of success in each trial. |
full |
Add the data frame showing x, mean, sd as well as the fx and derivatives |
In an rxode2() model, you can use llikGeom() but you have to
use the x and rate arguments. You can also get the derivative of prob with
llikGeomDprob().
data frame with fx for the log pdf value of with dProb
that has the derivatives with respect to the prob parameters at
the observation time-point
Matthew L. Fidler
llikGeom(1:10, 0.2)
et <- et(1:10)
et$prob <- 0.2
model <- function() {
model({
fx <- llikGeom(time, prob)
dProb <- llikGeomDprob(time, prob)
})
}
rxSolve(model, et)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.