| rxGetModel | R Documentation |
Normalizes the input to an rxModelVars object and optionally
rewrites the model text first: adding/stripping forward
sensitivity equations (calcSens/calcSens2/calcSens3),
adding/removing the df()/dy() Jacobian block (calcJac),
dropping LHS definitions (collapseModel), or converting to an
inductive linearization model (indLin).
rxGetModel(
model,
calcSens = NULL,
calcJac = NULL,
collapseModel = NULL,
indLin = FALSE,
calcSens2 = NULL,
calcSens3 = NULL
)
model |
The model to get the model variables from. It can
be: rxode2 model text (a character string, |
calcSens |
boolean indicating if rxode2 will calculate the
sensitivities according to the specified ODEs. May also be a
character vector of the states/parameters whose first-order
sensitivities ( |
calcJac |
boolean indicating if rxode2 will calculate the Jacobain according to the specified ODEs. |
collapseModel |
boolean indicating if rxode2 will remove all LHS variables when calculating sensitivities. |
indLin |
Calculate inductive linearization matrices and compile with inductive linearization support. |
calcSens2 |
character vector (or |
calcSens3 |
character vector (or |
An rxModelVars object of the (possibly rewritten) model
Matthew L. Fidler
rxGetModel("d/dt(depot) = -ka*depot; d/dt(central) = ka*depot - kel*central")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.