| rxIsStiff | R Documentation |
Returns TRUE for methods that are designed exclusively for stiff systems
and will never switch to a non-stiff algorithm. Solvers like "lsoda" and
"liblsoda" that automatically switch between stiff and non-stiff algorithms
return FALSE.
rxIsStiff(method)
method |
A character vector of method names or an integerish vector of
method codes (as returned by |
Stiff-only methods are:
"ros4" (13), "iem" (14), "cvode" (21), "ros43" (31), "ros6" (32),
"backwardEuler" (33), "gauss6" (34), "iiic6" (35), "radauiia5" (36),
"geng5" (37), "sdirk43" (38), "bdf" (107).
A logical vector the same length as method. TRUE if the
corresponding method is a purely stiff solver.
rxIsNonStiff(), rxIsImplicit(), odeMethodToInt()
rxIsStiff("bdf") # TRUE
rxIsStiff("lsoda") # FALSE (switches)
rxIsStiff("liblsoda") # FALSE (switches)
rxIsStiff(c("cvode", "dop853", "ros43")) # TRUE FALSE TRUE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.