Skip to contents

Get the last compiled model information as alist

Usage

rxLastCompile(what = c("msg", "stderr", "stdout", "c"))

Arguments

what

Which elements to message to the console; by default all of them. Use what="stderr" for the compiler error alone, or what=character(0) to message nothing and only take the returned list.

Value

A list contains the following elements:

  • msg the message for a bad compilation, or NULL if successful.

  • stdout the standard output from the compilation

  • stderr the standard error from the compilation

  • c the code code that was used

This list will be returned invisibly, but the function will also message the contents to the console.

Author

Matthew L. Fidler

Examples

# \donttest{
rxode2({
  a <- b
})
#>  
#>  
#> rxode2 5.1.7 model named rx_dd2f54ea34c10b7b8c35366fda9d8e8b model ( ready). 
#> value$params: b
#> value$lhs: a
rxLastCompile()
#> ── stderr ──────────────────────────────────────────────────────────────────────
#> using C compiler: ‘gcc (Ubuntu 13.3.0-6ubuntu2~24.04.1) 13.3.0’
# }