Get the last compiled model information as alist
Usage
rxLastCompile(what = c("msg", "stderr", "stdout", "c"))Value
A list contains the following elements:
msgthe message for a bad compilation, or NULL if successful.stdoutthe standard output from the compilationstderrthe standard error from the compilationcthe code code that was used
This list will be returned invisibly, but the function will also message the contents to the console.
Examples
# \donttest{
rxode2({
a <- b
})
#>
#>
#> rxode2 5.1.7 model named rx_dd2f54ea34c10b7b8c35366fda9d8e8b model (✔ ready).
#> value$params: b
#> value$lhs: a
rxLastCompile()
#> ── stderr ──────────────────────────────────────────────────────────────────────
#> using C compiler: ‘gcc (Ubuntu 13.3.0-6ubuntu2~24.04.1) 13.3.0’
# }