rxLastCompile: Get the last compiled model information as alist

rxLastCompileR Documentation

Get the last compiled model information as alist

Description

Get the last compiled model information as alist

Usage

rxLastCompile()

Value

A list contains the following elements:

  • msg the message for a bad compilation, or NULL if successful.

  • stdout the standard output from the compilation

  • stderr the standard error from the compilation

  • c the code code that was used

This list will be returned invisibly, but the function will also message the contents to the console.

Author(s)

Matthew L. Fidler

Examples


rxode2({
  a <- b
})
rxLastCompile()


rxode2 documentation built on July 28, 2026, 5:08 p.m.