| rxLastCompile | R Documentation |
Get the last compiled model information as alist
rxLastCompile()
A list contains the following elements:
msg the message for a bad compilation, or NULL if successful.
stdout the standard output from the compilation
stderr the standard error from the compilation
c the code code that was used
This list will be returned invisibly, but the function will also message the contents to the console.
Matthew L. Fidler
rxode2({
a <- b
})
rxLastCompile()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.