Simulate a from a Poisson process
Arguments
- n
Number of time points to simulate in the Poisson process
- lambda
Rate of Poisson process
- gamma
Asymmetry rate of Poisson process. When gamma=1.0, this simulates a homogenous Poisson process. When gamma<1.0, the Poisson process has more events early, when gamma > 1.0, the Poisson process has more events late in the process.
When gamma is non-zero, the tmax should not be infinite but indicate the end of the Poisson process to be simulated. In most pharamcometric cases, this will be the end of the study. Internally this uses a rate of:
l(t) = lambdagamma(t/tmax)^(gamma-1)
- prob
When specified, this is a probability function with one argument, time, that gives the probability that a Poisson time t is accepted as a rejection time.
- t0
the starting time of the Poisson process
- tmax
the maximum time of the Poisson process
- randomOrder
when
TRUErandomize the order of the Poisson events. By default (FALSE) it returns the Poisson process is in order of how the events occurred.
Value
This returns a vector of the Poisson process times; If the dropout is >= tmax, then all the rest of the times are = tmax to indicate the dropout is equal to or after tmax.
Examples
## Sample homogenous Poisson process of rate 1/10
rxPp(10, 1 / 10)
#> [1] 5.373507 6.157536 10.457261 14.931685 30.094087 45.962895 48.176397
#> [8] 49.219986 59.918107 61.079138
## Sample inhomogenous Poisson rate of 1/10
rxPp(10, 1 / 10, gamma = 2, tmax = 100)
#> [1] 11.77173 13.90262 42.98687 56.08295 65.99426 83.89567 100.00000
#> [8] 100.00000 100.00000 100.00000
## Typically the Poisson process times are in a sequential order,
## using randomOrder gives the Poisson process in random order
rxPp(10, 1 / 10, gamma = 2, tmax = 10, randomOrder = TRUE)
#> [1] 10 10 10 10 10 10 10 10 10 10
## This uses an arbitrary function to sample a non-homogenous Poisson process
rxPp(10, 1 / 10, prob = function(x) {
1/(1+abs(x))
})
#> [1] 0.6368274 29.7507782 30.3527555 81.0307358 164.0617555 190.9246293
#> [7] 358.4406680 460.7829216 586.1278906 694.0875654