| rxRawToC | R Documentation |
This function converts a raw vector or R object to C code that is used in the rxode2 model
rxRawToC(raw, type = c("xz", "base", "bzip2"))
raw |
vector or R object to convert |
type |
serialization type; one of "base", "xz" or "bzip2". |
raw vector for conversion to C in the codegen procedure
Matthew L. Fidler
rxRawToC(mtcars)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.