Differentiate and expand a matrix exponential model with forward sensitivities
Source:R/indLin.R
rxSensMatExp.RdDifferentiate and expand a matrix exponential model with forward sensitivities
Usage
rxSensMatExp(
model,
calcSens,
calcSens2 = NULL,
calcSens3 = NULL,
doConst = FALSE,
env = NULL
)Arguments
- model
rxode2 model, text, or function
- calcSens
A character vector of parameter names for which sensitivities should be calculated.
- calcSens2
character vector (or
NULL) requesting second-order sensitivitiesrx__sens_<x>_BY_<p>_BY_<q>__(povercalcSens,qovercalcSens2; everycalcSens2element must also be incalcSens). Expressed ask_from_tomicro-constant transfers like the first-order ones. Ignored forlinCmt()states (those use Stan forward-AD).- calcSens3
character vector (or
NULL) requesting third-order sensitivitiesrx__sens_<x>_BY_<p>_BY_<q>_BY_<r>__(rovercalcSens3). RequirescalcSens2; everycalcSens3element must also be incalcSens2.- doConst
Replace constants with values; By default this is
FALSE.- env
A pre-loaded symengine environment (from
.rxLoadPrune()) to reuse instead of reloadingmodel; whenNULLit is built internally.