Differentiate and expand a matrix exponential model with forward sensitivities
Source:R/indLin.R
rxSensMatExp.RdDifferentiate and expand a matrix exponential model with forward sensitivities

R/indLin.R
rxSensMatExp.RdDifferentiate and expand a matrix exponential model with forward sensitivities