rxSensMatExp: Differentiate and expand a matrix exponential model with...

View source: R/indLin.R

rxSensMatExpR Documentation

Differentiate and expand a matrix exponential model with forward sensitivities

Description

Differentiate and expand a matrix exponential model with forward sensitivities

Usage

rxSensMatExp(
  model,
  calcSens,
  calcSens2 = NULL,
  calcSens3 = NULL,
  doConst = FALSE,
  env = NULL
)

Arguments

model

rxode2 model, text, or function

calcSens

A character vector of parameter names for which sensitivities should be calculated.

calcSens2

character vector (or NULL) requesting second-order sensitivities ⁠rx__sens_<x>_BY_<p>_BY_<q>__⁠ (p over calcSens, q over calcSens2; every calcSens2 element must also be in calcSens). Expressed as k_from_to micro-constant transfers like the first-order ones. Ignored for linCmt() states (those use Stan forward-AD).

calcSens3

character vector (or NULL) requesting third-order sensitivities ⁠rx__sens_<x>_BY_<p>_BY_<q>_BY_<r>__⁠ (r over calcSens3). Requires calcSens2; every calcSens3 element must also be in calcSens2.

doConst

Replace constants with values; By default this is FALSE.

env

A pre-loaded symengine environment (from .rxLoadPrune()) to reuse instead of reloading model; when NULL it is built internally.

Value

A character string representing the matrix exponential sensitivity-expanded model code

Author(s)

Matthew L. Fidler


rxode2 documentation built on July 28, 2026, 5:08 p.m.