| rxSensMatExp | R Documentation |
Differentiate and expand a matrix exponential model with forward sensitivities
rxSensMatExp(
model,
calcSens,
calcSens2 = NULL,
calcSens3 = NULL,
doConst = FALSE,
env = NULL
)
model |
rxode2 model, text, or function |
calcSens |
A character vector of parameter names for which sensitivities should be calculated. |
calcSens2 |
character vector (or |
calcSens3 |
character vector (or |
doConst |
Replace constants with values; By default this is |
env |
A pre-loaded symengine environment (from |
A character string representing the matrix exponential sensitivity-expanded model code
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.