Skip to contents

This is useful when writing replacement UI functions

Usage

rxUdfUiFlag(expr, arg = "arg", funName = "fun", env = baseenv())

Arguments

expr

expression to evaluate

arg

argument name for error messages for the argument name in the rxUdfUi extension when the expression is not logical

funName

function name for the error message for the argument name in the rxUdfUi extension when the expression is not logical.

env

the environment in which to evaluate the expression (in case it is numeric)

Value

logical value of the expression if it can be evaluated to a scalar TRUE/FALSE value, otherwise an error is thrown.

Author

Matthew L. Fidler