Is the expression actually a flag that can be used in the rxUdfUi functions?
Source:R/rudfui.R
rxUdfUiFlag.RdThis is useful when writing replacement UI functions
Usage
rxUdfUiFlag(expr, arg = "arg", funName = "fun", env = baseenv())Arguments
- expr
expression to evaluate
- arg
argument name for error messages for the argument name in the
rxUdfUiextension when the expression is not logical- funName
function name for the error message for the argument name in the
rxUdfUiextension when the expression is not logical.- env
the environment in which to evaluate the expression (in case it is numeric)