This is used to determine if the location and scale parameters are actually equal to their default values, which allows for more efficient translation to expit expressions when possible.
Usage
rxUdfUiIsValue(expr, value, env = baseenv())This is used to determine if the location and scale parameters are actually equal to their default values, which allows for more efficient translation to expit expressions when possible.
rxUdfUiIsValue(expr, value, env = baseenv())