| rxUdfUiIsValue | R Documentation |
This is used to determine if the location and scale parameters are actually equal to their default values, which allows for more efficient translation to expit expressions when possible.
rxUdfUiIsValue(expr, value, env = baseenv())
expr |
the R language expression to evaluate |
value |
the value to compare against |
env |
the environment in which to evaluate the expression |
TRUE if the expression evaluates to a scalar value equal to the specified value, FALSE otherwise
Matthew L. Fidler
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.